@@ -1,9 +1,7 @@
 #
-# $Id: Scalar.pm,v 1.4 1998/10/05 19:28:22 jhi Exp jhi $
-#
 # Module:	Set::Scalar.pm
 #
-# Author:	Jarkko Hietaniemi <Jarkko.Hietaniemi@iki.fi>
+# Author:	Jarkko Hietaniemi <jhi@iki.fi>
 #
 # Purpose:	provide the basic set operations for Perl
 #		scalar/reference data.
@@ -35,7 +33,7 @@
 
 package Set::Scalar;
 
-$VERSION = 0.00401;
+$VERSION = 0.00402;
 
 require 5.002;
 
@@ -432,7 +430,7 @@ sub new {
       if ($r eq 'HASH') {
 	%m = %{$m};
 	$v = 1;
-	@new{keys %m} = values %m;
+	@new{keys %m} = CORE::values %m;
       } elsif ($r eq $SELF) {
 	$new{$m} = undef;
       } else {
@@ -469,7 +467,7 @@ sub inverse {
   @_ = _underload(@_);
 
   if (@_) {
-    @i = map { $i = new(%$_->{'_set'});
+    @i = map { $i = bless { %{$_[0]} }, ref $_[0];
 	       $i->{'_inverted'} = ! $_->{'_inverted'};
                $i->{'_valued'} = 0;
 	       $i } @_;
@@ -686,7 +684,7 @@ sub values {
   my (%m) = ();
 
   map {
-    @m{values %{$_->{'_set'}}} = undef;
+    @m{CORE::values %{$_->{'_set'}}} = undef;
   } @_;
 
   keys %m;
